@@ -91,7 +91,24 @@ ephy_embed_utils_address_has_web_scheme (const char *address)
 			  g_str_has_prefix (address, "file:") ||
 			  g_str_has_prefix (address, "data:") ||
 			  g_str_has_prefix (address, "about:") ||
+			  g_str_has_prefix (address, "javascript:") ||
+			  g_str_has_prefix (address, "mailto:") ||
 			  g_str_has_prefix (address, "gopher:"));
 
 	return has_web_scheme;
 }
+
+char*
+ephy_embed_utils_normalize_address (const char *address)
+{
+	char *effective_address;
+
+	g_return_val_if_fail (address, NULL);
+
+	if (ephy_embed_utils_address_has_web_scheme (address) == FALSE)
+		effective_address = g_strconcat ("http://", address, NULL);
+	else
+		effective_address = g_strdup (address);
+	
+	return effective_address;
+}
