@@ -13,16 +13,14 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-node-view.h 6588 2006-09-13 11:34:25Z chpe $
  */
 
 #ifndef __EPHY_NODE_VIEW_H
 #define __EPHY_NODE_VIEW_H
 
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkdnd.h>
+#include <gtk/gtk.h>
 
 #include "ephy-tree-model-node.h"
 #include "ephy-node-filter.h"
@@ -58,7 +56,8 @@ typedef enum
 	EPHY_NODE_VIEW_SHOW_PRIORITY = 1 << 0,
 	EPHY_NODE_VIEW_SORTABLE = 1 << 1,
 	EPHY_NODE_VIEW_EDITABLE = 1 << 2,
-	EPHY_NODE_VIEW_SEARCHABLE = 1 << 3
+	EPHY_NODE_VIEW_SEARCHABLE = 1 << 3,
+	EPHY_NODE_VIEW_ELLIPSIZED = 1 << 4
 } EphyNodeViewFlags;
 
 typedef struct
@@ -69,6 +68,7 @@ typedef struct
 	void (*node_activated)      (EphyNodeView *view, EphyNode *node);
 	void (*node_selected)       (EphyNodeView *view, EphyNode *node);
 	void (*node_dropped)        (EphyNodeView *view, EphyNode *node, GList *uris);
+	void (*node_middle_clicked) (EphyNodeView *view, EphyNode *node);
 } EphyNodeViewClass;
 
 GType      ephy_node_view_get_type	      (void);
@@ -131,4 +131,8 @@ void	   ephy_node_view_popup		      (EphyNodeView *view,
 
 G_END_DECLS
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #endif /* EPHY_NODE_VIEW_H */
