@@ -23,26 +23,25 @@
 
 #include "ephy-session.h"
 
+#include "eggdesktopfile.h"
+#include "eggsmclient.h"
+#include "ephy-bookmarks-editor.h"
+#include "ephy-debug.h"
 #include "ephy-embed.h"
 #include "ephy-embed-utils.h"
 #include "ephy-embed-container.h"
-#include "ephy-window.h"
-#include "ephy-shell.h"
-#include "ephy-history-window.h"
-#include "ephy-bookmarks-editor.h"
+#include "ephy-extension.h"
 #include "ephy-file-helpers.h"
 #include "eel-gconf-extensions.h"
-#include "ephy-prefs.h"
 #include "ephy-gui.h"
-#include "ephy-debug.h"
-#include "ephy-stock-icons.h"
-#include "ephy-glib-compat.h"
+#include "ephy-history-window.h"
 #include "ephy-notebook.h"
-#include "eggdesktopfile.h"
-#include "eggsmclient.h"
+#include "ephy-prefs.h"
+#include "ephy-shell.h"
+#include "ephy-stock-icons.h"
+#include "ephy-window.h"
 
 #include <glib/gi18n.h>
-#include <gio/gio.h>
 #include <gtk/gtk.h>
 
 #include <libxml/tree.h>
@@ -71,7 +70,7 @@ struct _EphySessionPrivate
 	GQueue *queue;
 	guint queue_idle_id;
 
-        GtkWidget *quit_interact_dialog;
+	GtkWidget *quit_interact_dialog;
 
 	guint dont_save : 1;
 	guint quit_while_resuming : 1;
@@ -100,13 +99,13 @@ G_DEFINE_TYPE_WITH_CODE (EphySession, ephy_session, G_TYPE_OBJECT,
 
 typedef struct
 {
-        EphySession *session;
-        EggSMClient *sm_client;
-        GtkWidget *dialog;
-        GtkWidget *label;
-        guint timeout_id;
-        guint ticks;
-        int response;
+	EphySession *session;
+	EggSMClient *sm_client;
+	GtkWidget *dialog;
+	GtkWidget *label;
+	guint timeout_id;
+	guint ticks;
+	int response;
 } InteractData;
 
 static void
@@ -163,15 +162,15 @@ static void
 confirm_shutdown_dialog_weak_ref_cb (InteractData *data,
 				     GObject *zombie)
 {
-        EphySessionPrivate *priv = data->session->priv;
-        EggSMClient *sm_client = data->sm_client;
+	EphySessionPrivate *priv = data->session->priv;
+	EggSMClient *sm_client = data->sm_client;
 	EphyShell *shell;
 	GObject *dv;
 	gboolean will_quit;
 
 	LOG ("confirm_shutdown_dialog_weak_ref_cb response %d", data->response);
 
-        priv->quit_interact_dialog = NULL;
+	priv->quit_interact_dialog = NULL;
 
 	shell = ephy_shell_get_default ();
 	if (shell != NULL)
@@ -198,15 +197,15 @@ confirm_shutdown_dialog_weak_ref_cb (InteractData *data,
 
 	g_free (data);
 
-        egg_sm_client_will_quit (sm_client, will_quit);
-        g_object_unref (sm_client);
+	egg_sm_client_will_quit (sm_client, will_quit);
+	g_object_unref (sm_client);
 }
 
 static void
 client_quit_requested_cb (EggSMClient *sm_client,
-                          EphySession *session)
+			  EphySession *session)
 {
-        EphySessionPrivate *priv = session->priv;
+	EphySessionPrivate *priv = session->priv;
 	GObject *dv;
 	GtkWidget *dialog, *box;
 	InteractData *data;
@@ -215,11 +214,11 @@ client_quit_requested_cb (EggSMClient *sm_client,
 	 * remaining, since they can't be restarted.
 	 */
 	if (ephy_shell_get_default () == NULL ||
-            (dv = ephy_embed_shell_get_downloader_view_nocreate (ephy_embed_shell_get_default ())) == NULL)
-        {
-                egg_sm_client_will_quit (sm_client, TRUE);
-                return;
-        }
+	    (dv = ephy_embed_shell_get_downloader_view_nocreate (ephy_embed_shell_get_default ())) == NULL)
+	{
+		egg_sm_client_will_quit (sm_client, TRUE);
+		return;
+	}
 
 	dialog = gtk_message_dialog_new
 		(NULL,
@@ -227,7 +226,7 @@ client_quit_requested_cb (EggSMClient *sm_client,
 		 GTK_MESSAGE_WARNING,
 		 GTK_BUTTONS_NONE,
 		 _("Abort pending downloads?"));
-        priv->quit_interact_dialog = dialog;
+	priv->quit_interact_dialog = dialog;
 
 	gtk_message_dialog_format_secondary_text
 		(GTK_MESSAGE_DIALOG (dialog),
@@ -245,8 +244,8 @@ client_quit_requested_cb (EggSMClient *sm_client,
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_REJECT);
 
 	data = g_new (InteractData, 1);
-        data->sm_client = g_object_ref (sm_client);
-        data->session = session;
+	data->sm_client = g_object_ref (sm_client);
+	data->session = session;
 	data->dialog = dialog;
 	data->response = GTK_RESPONSE_REJECT;
 
@@ -286,30 +285,30 @@ client_quit_requested_cb (EggSMClient *sm_client,
 
 static void
 client_quit_cancelled_cb (EggSMClient *sm_client,
-                          EphySession *session)
+			  EphySession *session)
 {
-        EphySessionPrivate *priv = session->priv;
+	EphySessionPrivate *priv = session->priv;
 
-        if (priv->quit_interact_dialog)
-        {
-                gtk_dialog_response (GTK_DIALOG (priv->quit_interact_dialog),
-                                     GTK_RESPONSE_DELETE_EVENT);
-        }
+	if (priv->quit_interact_dialog)
+	{
+		gtk_dialog_response (GTK_DIALOG (priv->quit_interact_dialog),
+				     GTK_RESPONSE_DELETE_EVENT);
+	}
 }
 
 static void
 client_quit_cb (EggSMClient *sm_client,
-                EphySession *session)
+		EphySession *session)
 {
-        LOG ("quit-cb");
+	LOG ("quit-cb");
 
-        ephy_session_close (session);
+	ephy_session_close (session);
 }
 
 static void
 client_save_state_cb (EggSMClient *sm_client,
-                      GKeyFile *keyfile,
-                      EphySession *session)
+		      GKeyFile *keyfile,
+		      EphySession *session)
 {
 	char *argv[] = { NULL, "--load-session", NULL };
 	char *discard_argv[] = { "rm", "-f", NULL };
@@ -381,7 +380,13 @@ load_status_notify_cb (EphyWebView *view,
 		       GParamSpec *pspec,
 		       EphySession *session)
 {
-	if (ephy_web_view_get_load_status (view) == FALSE)
+	WebKitLoadStatus status = webkit_web_view_get_load_status (WEBKIT_WEB_VIEW (view));
+
+	/* We won't know the URL we are loading in PROVISIONAL because
+	   of bug #593149, but save session anyway */
+	if (status == WEBKIT_LOAD_PROVISIONAL ||
+	    status == WEBKIT_LOAD_COMMITTED || 
+	    status == WEBKIT_LOAD_FINISHED)
 		ephy_session_save (session, SESSION_CRASHED);
 }
 
@@ -643,7 +648,7 @@ session_command_open_uris (EphySession *session,
 	{
 		const char *url = uris[i];
 		EphyNewTabFlags page_flags;
-		WebKitNetworkRequest *request;
+		WebKitNetworkRequest *request = NULL;
 
 		if (url[0] == '\0')
 		{
@@ -652,9 +657,9 @@ session_command_open_uris (EphySession *session,
 		else
 		{
 			page_flags = EPHY_NEW_TAB_OPEN_PAGE;
+			request = webkit_network_request_new (url);
 		}
 
-		request = webkit_network_request_new (url);
 		embed = ephy_shell_new_tab_full (shell, window,
 						 NULL /* parent tab */,
 						 request,
@@ -662,7 +667,8 @@ session_command_open_uris (EphySession *session,
 						 EPHY_WEB_VIEW_CHROME_ALL,
 						 FALSE /* is popup? */,
 						 user_time);
-		g_object_unref (request);
+		if (request)
+			g_object_unref (request);
 
 		window = EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (embed)));
 	}
@@ -837,7 +843,7 @@ static void
 ephy_session_init (EphySession *session)
 {
 	EphySessionPrivate *priv;
-        EggSMClient *sm_client;
+	EggSMClient *sm_client;
 
 	LOG ("EphySession initialising");
 
@@ -845,15 +851,15 @@ ephy_session_init (EphySession *session)
 
 	priv->queue = g_queue_new ();
 
-        sm_client = egg_sm_client_get ();
-        g_signal_connect (sm_client, "save-state",
-                          G_CALLBACK (client_save_state_cb), session);
-        g_signal_connect (sm_client, "quit-requested",
-                          G_CALLBACK (client_quit_requested_cb), session);
-        g_signal_connect (sm_client, "quit-cancelled",
-                          G_CALLBACK (client_quit_cancelled_cb), session);
-        g_signal_connect (sm_client, "quit",
-                          G_CALLBACK (client_quit_cb), session);
+	sm_client = egg_sm_client_get ();
+	g_signal_connect (sm_client, "save-state",
+			  G_CALLBACK (client_save_state_cb), session);
+	g_signal_connect (sm_client, "quit-requested",
+			  G_CALLBACK (client_quit_requested_cb), session);
+	g_signal_connect (sm_client, "quit-cancelled",
+			  G_CALLBACK (client_quit_cancelled_cb), session);
+	g_signal_connect (sm_client, "quit",
+			  G_CALLBACK (client_quit_cb), session);
 }
 
 static void
@@ -861,7 +867,7 @@ ephy_session_dispose (GObject *object)
 {
 	EphySession *session = EPHY_SESSION (object);
 	EphySessionPrivate *priv = session->priv;
-        EggSMClient *sm_client;
+	EggSMClient *sm_client;
 
 	LOG ("EphySession disposing");
 
@@ -875,9 +881,9 @@ ephy_session_dispose (GObject *object)
 
 	session_command_queue_clear (session);
 
-        sm_client = egg_sm_client_get ();
-        g_signal_handlers_disconnect_matched (sm_client, G_SIGNAL_MATCH_DATA,
-                                              0, 0, NULL, NULL, session);
+	sm_client = egg_sm_client_get ();
+	g_signal_handlers_disconnect_matched (sm_client, G_SIGNAL_MATCH_DATA,
+					      0, 0, NULL, NULL, session);
 
 	G_OBJECT_CLASS (ephy_session_parent_class)->dispose (object);
 }
@@ -1040,7 +1046,7 @@ write_tab (xmlTextWriterPtr writer,
 					   (const xmlChar *) title);
 	if (ret < 0) return ret;
 
-	if (ephy_web_view_get_load_status (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed)))
+	if (ephy_web_view_is_loading (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed)))
 	{
 		ret = xmlTextWriterWriteAttribute (writer,
 						   (const xmlChar *) "loading",
@@ -1268,7 +1274,87 @@ out:
 	return ret >= 0 ? TRUE : FALSE;
 }
 
-static void
+
+static void 
+confirm_before_recover (EphyWindow* window, char* url, char* title)
+{
+	
+	GtkWidget *embed; 
+	GString *html = g_string_new ("");
+	char *message = g_markup_printf_escaped
+		/* Translators: %s refers to the LSB distributor ID, for instance MandrivaLinux */
+		(_("This page was loading when the web browser closed unexpectedly. "
+		   "This might happen again if you reload the page. If it does, please report "
+		   "the problem to the %s developers."),
+		   LSB_DISTRIBUTOR);
+
+	const char *format =  
+	  "<?xml version=\"1.0\" encoding=\"utf-8\"?>"
+	  "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">"
+	  "<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"%s\" xml:lang=\"%s\">" /* language (twice) */
+	  "<head>"
+	  "<title>"
+	  "%s" /* web title */
+	  "</title>"
+	  "<style type=\"text/css\">"
+	  "div#body {"
+	  "top: 12px;"
+	  "right: 12px;"
+	  "bottom: 12px;"
+	  "left: 12px;"
+	  "overflow: auto;"
+	  "background-color:#dcdad5;"
+	  "font: message-box;"
+	  "border: 1px solid;"
+	  "background-repeat: no-repeat;"
+	  "background-position: center left;"
+	  "padding: 12px 12px 12px 72px;"
+	  "text-align:left;"
+		
+	  "h1 {"
+	  
+	  "margin: 0;"
+	  "font-size: 1.2em;"
+	  
+	  "}"
+	  "</style>"
+	
+	  "</head>"
+
+	  "<body dir=\"%s\">" /* rtl or ltr */
+	  "<div id=\"body\">"
+
+	  "<h1>"
+	  "%s" /* head of the message */
+	  "</h1>"
+
+	  "<p> %s </p>"	  /* message */
+
+	  "</div>"
+	  "</body>"
+	  "</html>";
+
+	char *language = g_strdup (pango_language_to_string (gtk_get_default_language ()));
+	g_strdelimit (language, "_-@", '\0');
+
+	g_string_printf (html, format, language, language, title, 
+			 gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL ? "rtl" : "ltr", 
+			 _("Blank page"), message);
+
+	embed  = (GtkWidget*) ephy_shell_new_tab (ephy_shell, window, NULL, NULL, 
+						  EPHY_NEW_TAB_IN_EXISTING_WINDOW | EPHY_NEW_TAB_APPEND_LAST);
+
+	/* show generated html and put the original URL in the navigation bar */
+	webkit_web_view_load_html_string (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed),
+					  html->str, 
+					  url);	
+	g_string_free (html, TRUE);
+	g_free (message);
+	g_free (language);
+}
+
+
+static void 
 parse_embed (xmlNodePtr child,
 	     EphyWindow *window,
 	     EphySession *session)
@@ -1290,10 +1376,15 @@ parse_embed (xmlNodePtr child,
 			xmlFree (attr);
 
 			url = xmlGetProp (child, (const xmlChar *) "url");
-			if (url == NULL) continue;
+			if (url == NULL) 
+				continue;
 
-			/* about:recover is not implemented, so tabs
-			   loading during crash wont be recovered (bug #583953) */
+			/* in the case that crash happens before we receive the URL from the server,
+			   this will open an about:blank tab. See http://bugzilla.gnome.org/show_bug.cgi?id=591294
+
+			   Otherwise, if the web was fully loaded, it is reloaded again.
+			
+			*/
 			if (!was_loading ||
 			    strcmp ((const char *) url, "about:blank") == 0)
 			{
@@ -1304,6 +1395,17 @@ parse_embed (xmlNodePtr child,
 						    EPHY_NEW_TAB_OPEN_PAGE |
 						    EPHY_NEW_TAB_APPEND_LAST);
 			}
+			else if (was_loading && url != NULL &&
+				 strcmp ((const char *) url, "about:blank") != 0)
+			{
+				/* shows a message to the user that warns that this page was
+				   loading during crash and make Epiphany crash again,
+				   in this case we know the URL */
+
+				xmlChar* title = xmlGetProp (child, (const xmlChar *) "title");
+			
+				confirm_before_recover (window, (char*) url, (char*) title);
+			}
 
 			xmlFree (url);
 		}
@@ -1450,7 +1552,7 @@ ephy_session_load (EphySession *session,
 			}
 
 			gtk_widget_grab_focus (GTK_WIDGET (ephy_embed_container_get_active_child
-                                                           (EPHY_EMBED_CONTAINER (window))));
+							   (EPHY_EMBED_CONTAINER (window))));
 			gtk_widget_show (widget);
 		}
 		else if (xmlStrEqual (child->name, (const xmlChar *) "toolwindow"))
@@ -1499,7 +1601,8 @@ ephy_session_load (EphySession *session,
  * ephy_session_get_windows:
  * @session: the #EphySession
  *
- * Returns: the list of open #EphyWindow:s.
+ * Returns: (element-type EphyWindow) (transfer container): the list of
+ *          open #EphyWindow:s.
  **/
 GList *
 ephy_session_get_windows (EphySession *session)
@@ -1557,13 +1660,14 @@ ephy_session_remove_window (EphySession *session,
  * need to take an action (like opening an url) on
  * a window but you dont have a target window.
  *
- * Return value: the current active non-popup browser window, or NULL of there is none.
+ * Return value: (transfer none): the current active non-popup browser
+ *               window, or NULL of there is none.
  **/
 EphyWindow *
 ephy_session_get_active_window (EphySession *session)
 {
-        EphyWindow *window = NULL;
-        EphyEmbedContainer *w;
+	EphyWindow *window = NULL;
+	EphyEmbedContainer *w;
 	GList *l;
 
 	g_return_val_if_fail (EPHY_IS_SESSION (session), NULL);
@@ -1574,7 +1678,7 @@ ephy_session_get_active_window (EphySession *session)
 
 		if (ephy_embed_container_get_is_popup (w) == FALSE)
 		{
-                        window = EPHY_WINDOW (w);
+			window = EPHY_WINDOW (w);
 			break;
 		}
 	}
