@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  Copyright © 2000-2004 Marco Pesenti Gritti
  *  Copyright © 2003, 2004, 2006 Christian Persch
@@ -358,7 +359,7 @@ ephy_shell_finalize (GObject *object)
  *
  * Retrieve the default #EphyShell object
  *
- * ReturnValue: the default #EphyShell
+ * Return value: (transfer none): the default #EphyShell
  **/
 EphyShell *
 ephy_shell_get_default (void)
@@ -416,7 +417,7 @@ load_homepage (EphyEmbed *embed)
  * Create a new tab and the parent window when necessary.
  * Use this function to open urls in new window/tabs.
  *
- * ReturnValue: the created #EphyEmbed
+ * Return value: (transfer none): the created #EphyEmbed
  **/
 EphyEmbed *
 ephy_shell_new_tab_full (EphyShell *shell,
@@ -431,6 +432,7 @@ ephy_shell_new_tab_full (EphyShell *shell,
 	EphyWindow *window;
 	EphyEmbed *embed = NULL;
 	gboolean in_new_window = TRUE;
+	gboolean open_page = FALSE;
 	gboolean jump_to;
 	gboolean active_is_blank = FALSE;
 	GtkWidget *nb;
@@ -438,11 +440,13 @@ ephy_shell_new_tab_full (EphyShell *shell,
 	gboolean is_empty = FALSE;
 	EphyToolbar *toolbar;
 
+	if (flags & EPHY_NEW_TAB_OPEN_PAGE) open_page = TRUE;
 	if (flags & EPHY_NEW_TAB_IN_NEW_WINDOW) in_new_window = TRUE;
 	if (flags & EPHY_NEW_TAB_IN_EXISTING_WINDOW) in_new_window = FALSE;
 
 	in_new_window = in_new_window && !eel_gconf_get_boolean (CONF_LOCKDOWN_FULLSCREEN);
 	g_return_val_if_fail (in_new_window || !is_popup, NULL);
+	g_return_val_if_fail (open_page == (gboolean)(request != NULL), NULL);
 
 	jump_to = (flags & EPHY_NEW_TAB_JUMP) != 0;
 
@@ -474,7 +478,8 @@ ephy_shell_new_tab_full (EphyShell *shell,
 		embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 		if (embed != NULL)
 		{
-			if (ephy_web_view_get_is_blank (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed)))
+			if (ephy_web_view_get_is_blank (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed)) &&
+			    ephy_web_view_is_loading (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed)) == FALSE)
 			{
 				active_is_blank = TRUE;
 			}
@@ -491,8 +496,8 @@ ephy_shell_new_tab_full (EphyShell *shell,
 
 	if (previous_embed != NULL)
 	{	
-                ephy_web_view_copy_back_history (EPHY_WEB_VIEW (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (previous_embed)),
-                                                 EPHY_WEB_VIEW (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed)));
+                ephy_web_view_copy_back_history (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (previous_embed),
+                                                 EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed));
 	}		
 
 	ephy_gui_window_update_user_time (GTK_WIDGET (window), user_time);
@@ -510,14 +515,13 @@ ephy_shell_new_tab_full (EphyShell *shell,
 	if (flags & EPHY_NEW_TAB_HOME_PAGE ||
 	    flags & EPHY_NEW_TAB_NEW_PAGE)
 	{
-		ephy_web_view_set_typed_address (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed), "",
-						 EPHY_WEB_VIEW_ADDRESS_EXPIRE_NEXT);
+		ephy_web_view_set_typed_address (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed), "");
 		ephy_toolbar_activate_location (toolbar);
 		is_empty = load_homepage (embed);
 	}
 	else if (flags & EPHY_NEW_TAB_OPEN_PAGE)
 	{
-                ephy_web_view_load_request (EPHY_WEB_VIEW (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed)),
+                ephy_web_view_load_request (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed),
                                             request);
 
 		is_empty = url_is_empty (webkit_network_request_get_uri (request));
@@ -557,7 +561,7 @@ ephy_shell_new_tab_full (EphyShell *shell,
  * Create a new tab and the parent window when necessary.
  * Use this function to open urls in new window/tabs.
  *
- * ReturnValue: the created #EphyEmbed
+ * Return value: (transfer none): the created #EphyEmbed
  **/
 EphyEmbed *
 ephy_shell_new_tab (EphyShell *shell,
@@ -567,12 +571,14 @@ ephy_shell_new_tab (EphyShell *shell,
 		    EphyNewTabFlags flags)
 {
 	EphyEmbed *embed;
-	WebKitNetworkRequest *request = webkit_network_request_new (url);
+	WebKitNetworkRequest *request = url ? webkit_network_request_new (url) : NULL;
 
 	embed = ephy_shell_new_tab_full (shell, parent_window,
 					 previous_embed, request, flags,
 					 EPHY_WEB_VIEW_CHROME_ALL, FALSE, 0);
-        g_object_unref (request);
+
+	if (request)
+		g_object_unref (request);
 
 	return embed;
 }
@@ -583,7 +589,7 @@ ephy_shell_new_tab (EphyShell *shell,
  *
  * Returns current session.
  *
- * Return value: the current session.
+ * Return value: (transfer none): the current session.
  **/
 GObject *
 ephy_shell_get_session (EphyShell *shell)
@@ -633,6 +639,11 @@ ephy_shell_get_lockdown (EphyShell *shell)
 	return G_OBJECT (shell->priv->session);
 }
 
+/**
+ * ephy_shell_get_bookmarks:
+ *
+ * Return value: (transfer none):
+ **/
 EphyBookmarks *
 ephy_shell_get_bookmarks (EphyShell *shell)
 {
@@ -644,6 +655,11 @@ ephy_shell_get_bookmarks (EphyShell *shell)
 	return shell->priv->bookmarks;
 }
 
+/**
+ * ephy_shell_get_toolbars_model:
+ *
+ * Return value: (transfer none):
+ **/
 GObject *
 ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
 {
@@ -690,6 +706,11 @@ ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
 	}
 }
 
+/**
+ * ephy_shell_get_extensions_manager:
+ *
+ * Return value: (transfer none):
+ **/
 GObject *
 ephy_shell_get_extensions_manager (EphyShell *es)
 {
@@ -711,6 +732,11 @@ ephy_shell_get_extensions_manager (EphyShell *es)
 	return G_OBJECT (es->priv->extensions_manager);
 }
 
+/**
+ * ephy_shell_get_net_monitor:
+ *
+ * Return value: (transfer none):
+ **/
 GObject *
 ephy_shell_get_net_monitor (EphyShell *shell)
 {
@@ -754,6 +780,11 @@ toolwindow_hide_cb (GtkWidget *widget, EphyShell *es)
 	g_object_unref (ephy_shell);
 }
 
+/**
+ * ephy_shell_get_bookmarks_editor:
+ *
+ * Return value: (transfer none):
+ **/
 GtkWidget *
 ephy_shell_get_bookmarks_editor (EphyShell *shell)
 {
@@ -774,6 +805,11 @@ ephy_shell_get_bookmarks_editor (EphyShell *shell)
 	return shell->priv->bme;
 }
 
+/**
+ * ephy_shell_get_history_window:
+ *
+ * Return value: (transfer none):
+ **/
 GtkWidget *
 ephy_shell_get_history_window (EphyShell *shell)
 {
@@ -795,6 +831,11 @@ ephy_shell_get_history_window (EphyShell *shell)
 	return shell->priv->history_window;
 }
 
+/**
+ * ephy_shell_get_pdm_dialog:
+ *
+ * Return value: (transfer none):
+ **/
 GObject *
 ephy_shell_get_pdm_dialog (EphyShell *shell)
 {
@@ -813,6 +854,11 @@ ephy_shell_get_pdm_dialog (EphyShell *shell)
 	return shell->priv->pdm_dialog;
 }
 
+/**
+ * ephy_shell_get_prefs_dialog:
+ *
+ * Return value: (transfer none):
+ **/
 GObject *
 ephy_shell_get_prefs_dialog (EphyShell *shell)
 {
